<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Theme Palace
 * @subpackage Yummy Pro
 * @since Yummy Pro 1.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function yummy_pro_body_classes( $classes ) {
	$options = yummy_pro_get_theme_options();

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Add a class for header typography
	$header_typography = ! empty( $options['header_theme_typography'] ) ? $options['header_theme_typography'] : 'default';
	$classes[] = esc_attr( $header_typography );

	// Add a class for body typography
	$body_typography = ! empty( $options['body_theme_typography'] ) ? $options['body_theme_typography'] : 'default';
	$classes[] = esc_attr( $body_typography );

	// Add a class for single pages and posts title typography
	$page_post_title_font = ! empty( $options['page_post_title_font'] ) ? $options['page_post_title_font'] : 'default';
	$classes[] = esc_attr( $page_post_title_font );

	// Add a class for front page section title typography
	$front_page_sections_title_font = ! empty( $options['front_page_sections_title_font'] ) ? $options['front_page_sections_title_font'] : 'default';
	$classes[] = esc_attr( $front_page_sections_title_font );

	// Add a class for layout
	$classes[] = esc_attr( $options['site_layout'] );

	// Add a class for sidebar
	$sidebar_position = yummy_pro_layout();

	$selected_sidebar = get_post_meta( get_the_id(), 'yummy-pro-selected-sidebar', true );
	$post_sidebar = ! empty( $selected_sidebar ) ? $selected_sidebar : 'sidebar-1';

	if ( is_active_sidebar( $post_sidebar ) ) {
		$classes[] = esc_attr( $sidebar_position );
	} else {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'yummy_pro_body_classes' );

if ( ! function_exists( 'yummy_pro_add_search_box_to_menu' ) ) :
    /**
     * Add search box to menu
     * @param  $items,$args
   * * @return html,$items
     */

    function yummy_pro_add_search_box_to_menu( $items, $args ) {
        
        $options = yummy_pro_get_theme_options();
        $disable_search = $options['disable_search'];
        if( $args->theme_location == 'primary' ) {        

            // Search Box
            if ( $disable_search ) {
                $search = '';
                $html = $items;
            } 
            else {
                $search 	= '<div class="search" id="search">' . get_search_form(false) . '</div>';
                if ( class_exists( 'WooCommerce' ) && ( true != $options['disable_add_to_cart'] ) ) {
                	$html 		= $items . '<li><a class="cart-icon" href="'. esc_url( wc_get_cart_url() ) .'"><i class="fa fa-shopping-cart" aria-hidden="true"></i><strong>'. wp_kses_data( WC()->cart->get_cart_contents_count() ) .'</strong></li><li><a id="search-btn" href="#"><i class="fa fa-search"></i></a></li>' . '</ul>' . $search;
				} else {
					$html 		= $items . '<li><a id="search-btn" href="#"><i class="fa fa-search"></i></a></li>' . '</ul>' . $search;
				}

            }

            return $html;      
        }
        return $items;
    }
endif;
add_filter('wp_nav_menu_items','yummy_pro_add_search_box_to_menu', 10, 2);