<?php 
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Yummy Pro
 * @since Yummy Pro 1.0
 */
if ( ! function_exists( 'yummy_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Yummy Pro 1.0
    */
    function yummy_pro_add_about_section() {
        // Check if about is enabled
        $enable_about = apply_filters( 'yummy_pro_section_status', true, 'enable_about' );

        if ( true !== $enable_about ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'yummy_pro_filter_about_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render about section now.
        yummy_pro_render_about_section( $section_details );
    }
endif;
add_action( 'yummy_pro_primary_content_action', 'yummy_pro_add_about_section', 20 );


if ( ! function_exists( 'yummy_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Yummy Pro 1.0
    * @param array $input about section details.
    */
    function yummy_pro_get_about_section_details( $input ) {
        $options = yummy_pro_get_theme_options();

        // about type
        $about_content_type  = $options['about_content_type'];

        $content = array();
        switch ( $about_content_type ) {
          	case 'demo':
                $content['title']     = esc_html__( 'About', 'yummy-pro' );
                $content['excerpt']   = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam suscipit feugiat purus vel egestas. Praesent ac tristique libero, eget luctus arcu. Donec lectus ante, posuere eu gravida in, porttitor et lorem.Nunc sem nulla, pellentesque a pharetra eu, pulvinar eu eros. Cras ullamcorper efficitur placerat. Nam tristique nisi in nisi viverra, in mattis massa molestie. Suspendisse semper elementum lacus, ut placerat odio congue ac. Vivamus pellentesque sapien vitae suscipit luctus. Praesent eu sem at felis porttitor convallis id vitae odio.','yummy-pro' );
            break;        

          	case 'page':
                $post_id = null;
                if ( isset( $options[ 'about_page' ] ) ) {
                    $post_id = $options[ 'about_page' ];
                }                    
            break;

            case 'post':
                $post_id = null;
                if ( isset( $options[ 'about_post' ] ) ) {
                    $post_id = $options[ 'about_post' ];
                }                         
          	break;
        }

        if ( in_array( $about_content_type, array( 'post', 'page' ) ) ) {
            // Fetch posts.
            if ( ! empty( $post_id ) ) {
                $content['title']       = get_the_title( $post_id );
                $content['excerpt']     = yummy_pro_trim_content( 100, get_post( $post_id ) );
            }
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'yummy_pro_filter_about_section_details', 'yummy_pro_get_about_section_details' );


if ( ! function_exists( 'yummy_pro_render_about_section' ) ) :
    /**
    * Start about section
    *
    * @return string about content
    * @since Yummy Pro 1.0
    *
    */
    function yummy_pro_render_about_section( $content_details = array() ) {
        $options = yummy_pro_get_theme_options();

        if ( empty( $content_details ) ) {
          return;
        }
        $titles = array( esc_html__( 'Guests','yummy-pro' ), esc_html__( 'Date','yummy-pro' ), esc_html__( 'Time','yummy-pro' ) );
        $values = array( esc_html__( '03','yummy-pro' ), esc_html__( '16 sep','yummy-pro' ), esc_html__( '19:00','yummy-pro' ) );
        for( $i=0; $i<=2; $i++) {
            $reserved[$i]['reservation_title'] = $titles[$i];
            $reserved[$i]['reservation_values'] = $values[$i];
        }
        if( ( $options['about_content_type'] == 'demo' ) || is_active_sidebar( 'about_section_widget_area' ) ) {
            $addcolumn = 2;
        }
        else {
            $addcolumn = 1;
        }
        ?>
        <section id="reservation-information" class="col-<?php echo $addcolumn; ?>">
            <div class="wrapper">
                <div class="column-wrapper">
                <?php if( $options['about_content_type'] == 'demo' ) { ?>
                    <div class="reservation-info-wrapper">
                        <div class="entry-header-logo">
                            <img src="<?php echo get_template_directory_uri().'/assets/uploads/separator-01.png'; ?>" alt="<?php esc_attr_e( 'logo','yummy-pro' ); ?>">
                        </div><!-- .entry-header-logo -->   
                        <h2 class="entry-title"><?php esc_html_e( 'Reservations','yummy-pro' ); ?></h2>
                        <?php foreach ( $reserved as $reserve ) { ?>
                            <div class="reservation-info clear">
                                <span><?php echo esc_html( $reserve['reservation_title'] ); ?></span>
                                <strong><?php echo esc_html( $reserve['reservation_values'] ); ?></strong>
                            </div><!-- .reservation-info -->
                        <?php } ?>
                        <a href="#" class="more-link fill-black"><?php esc_html_e( 'Check Availability','yummy-pro' ); ?></a>
                    </div><!-- .reservation-info-wrapper -->
                    <?php }
                    else {
                        if( is_active_sidebar( 'about_section_widget_area' ) ) {
                            dynamic_sidebar( 'about_section_widget_area' ); 
                        } 
                    } ?>
                </div><!--.column-wrapper-->                

                <div class="column-wrapper">
                    <div class="page-section">
                        <header class="entry-header">
                            <h2 class="entry-title"><?php echo esc_html( $content_details['title'] ); ?></h2>
                        </header><!--.entry-header-->
                        <?php if( ! empty( $content_details['excerpt'] ) ) { ?>
                            <div class="entry-content">
                                <p><?php echo esc_html( $content_details['excerpt'] ); ?></p>
                            </div><!--.entry-content-->
                        <?php } ?>
                    </div><!-- .page-section -->
                </div><!--.column-wrapper-->
            </div><!--.wrapper-->
        </section><!--#reservation-form--> 
    <?php }
endif;